#
# spec file for package tn5250
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tn5250
Version:        0.16.5
Release:        472.3
Summary:        5250 Emulator
License:        LGPL-2.1-or-later
Group:          Productivity/Networking/Other
URL:            http://tn5250.sourceforge.net/
Source:         https://sourceforge.net/projects/tn5250/files/tn5250/0.16.5/tn5250-0.16.5.tar.gz
Source1:        README.SUSE
Patch0:         tn5250-0.16.2-terminfo.dif
Patch1:         tn5250-0.16.5-strings.patch
Patch2:         tn5250-0.16.5-no-build-date.patch
Patch3:         tn5250-gcc14.patch
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  ncurses-devel

%description
The 5250 is most commonly used for connecting to IBM's AS/400.	While
one can connect to an AS/400 with a VT100 emulator, it is not ideal.
The problem is that the 5250 is a screen at a time terminal, whereas
the VT100 is a character at a time device.  The emulator uses telnet's
binary mode to transfer the 5250 data stream.

%package -n lib5250-0
Summary:        Component library of the tn5250 emulator
Group:          System/Libraries

%description -n lib5250-0
Component library of the tn5250 emulator.

%package devel
Summary:        Header files for the 5250 Emulator
Group:          Productivity/Networking/Other
Provides:       tn5250:/usr/include/tn5250/tn5250d.h
Requires:       lib5250-0 = %{version}

%description devel
Header files for use with the tn5250 library.

%prep
%setup
%patch -P 0 -p1
%patch -P 1
%patch -P 2
%patch -P 3 -p1
cp -p %{SOURCE1} .

%build
DIR=$(find . -name configure -printf "%h\n")
%{?suse_update_config:%{suse_update_config -f $DIR }}
autoreconf -f -i
%configure --disable-static
%make_build

%install
mkdir -p "%{buildroot}/%{_bindir}"
%make_install
rm -f %{buildroot}%{_libdir}/*.la

%post   -n lib5250-0 -p /sbin/ldconfig
%postun -n lib5250-0 -p /sbin/ldconfig

%files
%license COPYING
%doc BUGS README AUTHORS BUGS ChangeLog NEWS TODO XTerm README.SUSE
/usr/bin/*
%{_mandir}/man1/*
%{_mandir}/man5/*
/usr/share/tn5250

%files -n lib5250-0
%{_libdir}/lib5250.so.0
%{_libdir}/lib5250.so.0.0.0

%files devel
/usr/include/tn5250.h
/usr/include/tn5250
%{_libdir}/lib5250.so
/usr/share/aclocal/tn5250.m4

%changelog
* Thu Jul 25 2024 Marcus Meissner <meissner@suse.com>
- tn5250-gcc14.patch: fixed build failure with gcc14
* Mon Feb 26 2024 pgajdos@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Fri Apr 29 2022 Marcus Meissner <meissner@suse.com>
- switched source url to https
* Mon Jun 14 2021 Jan Engelhardt <jengelh@inai.de>
- Implement shared library packaging policy.
- Remove --with-pic (no effect with --disable-static).
- Remove old specfile constructs.
* Mon Nov 13 2017 dimstar@opensuse.org
- Rename README.SuSE to README.SUSE, adhering to the correct
  spelling.
* Wed Oct  8 2014 jengelh@inai.de
- Remove old specfile tags and sections
* Tue Nov 29 2011 aj@suse.de
- Fix download URL, use gz package from upstream.
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Sun Aug 29 2010 cristian.rodriguez@opensuse.org
- Do not include build date in binaries
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Tue Jun  5 2007 ro@suse.de
- added ldconfig to post scripts
* Tue Jun  5 2007 ro@suse.de
- split off devel package
* Thu Mar 29 2007 rguenther@suse.de
- add ncurses-devel BuildRequires
* Tue Dec 12 2006 jplack@suse.de
- moved xt5250 from /usr/X11R6/bin to /usr/bin (#227443)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Mon Sep  8 2003 poeml@suse.de
- README: <feedback@suse.de> -> <http://www.suse.com/feedback>
* Wed May 14 2003 poeml@suse.de
- use %%defattr
- add tn5250.m4
* Tue Jan 14 2003 nadvornik@suse.cz
- fixed multi-line string literals
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Wed Aug  7 2002 poeml@suse.de
- update to 0.16.5
  - [...] Added ssl_method config option so you can specify an ssl
    method of ssl2, ssl3 or auto.  (Problems connecting were
    reported in some circumstances if ssl3 is not specified)
* Tue Jul 30 2002 poeml@suse.de
- update to latest stable release 0.16.4. New features include:
  - SSL client-side certificates now supported
  - Changed license to LGPL
  - Added the scs2pdf print filter (to transform SCS printer
    streams to PDF files)
  - Added support for re-mapping the screen colors.
  - Many, many bug fixes.
* Tue Jul  2 2002 meissner@suse.de
- run autoreconf
* Tue May 28 2002 sf@suse.de
- added %%{_lib} fixes
* Mon Mar  4 2002 poeml@suse.de
- add tn5250-0.16.2-terminfo.dif: use the xterm terminfo entry if
  an xterm-5250 one doesn't exist. This fixes the startup of the
  xt5250 command.
* Fri Aug 24 2001 poeml@suse.de
- update to 0.16.2: xt5250 does work now; better handling of
  OS/400 special function keys
- add the files AUTHORS, BUGS, ChangeLog, NEWS, TODO, XTerm to the
  documentation, and update README.SuSE
- drop the two patches (obsoleted)
- build in Buildroot
* Fri Mar 30 2001 poeml@suse.de
- use suse_update_config macro to update automake, autoconf and
  libtool
- don't use #ifdef directives inside macro args (printf)
- rework README.SuSE
- bzip2'ed sources
* Thu Mar 22 2001 poeml@suse.de
- add README.SuSE
* Wed Mar  7 2001 poeml@suse.de
- add a patch that removes some assertions that will always fail if
  a strange character is encountered, e.g. in the linux boot logs
- fix RPM Group tag
* Tue Feb  1 2000 ro@suse.de
- update to 0.15.6 to make it compile
  (adds manpages libs tools)
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jul  7 1998 hf@suse.de
- initial package
